==> oarepo-cli-11.0.1.tar.gz: oarepo-cli-11.0.1/oarepo_cli/cli/initialize/step_04_install_invenio_cli.py <==
from __future__ import annotations

import os
import shutil
import venv
from pathlib import Path

from oarepo_cli.ui.wizard import WizardStep

from ...utils import run_cmdline


class InstallInvenioCliStep(WizardStep):
    def __init__(self, **kwargs):
        super().__init__(
            heading="""I will install invenio command-line client. I will use the client to check that
you have all the tools installed (python, docker, ...). If this step fails, please fix the problem
and run this wizard again.

Before the installation, you may have a look at the requirements at
https://inveniordm.docs.cern.ch/install/requirements/ .
            """,
            **kwargs,
        )

    def after_run(self):
        print("Creating invenio-cli virtualenv")
        invenio_cli_dir = self._invenio_cli_dir
        self.data["invenio_cli"] = str(
            (invenio_cli_dir / "bin" / "invenio-cli").relative_to(self.data.project_dir)
        )
        if invenio_cli_dir.exists():
            shutil.rmtree(invenio_cli_dir)
        venv.main([str(invenio_cli_dir)])
        pip_binary = invenio_cli_dir / "bin" / "pip"

        invenio_cli_version=os.environ.get('INVENIO_CLI_VERSION', '1.0.16')

        run_cmdline(
            pip_binary, "install", "-U", "--no-input", "setuptools", "pip", "wheel"
        )
        run_cmdline(pip_binary, "install", "--no-input", f"invenio-cli=={invenio_cli_version}")
        
        with open(invenio_cli_dir / ".install.ok", "w") as f:
            f.write("invenio installation ok")

    @property
    def _invenio_cli_dir(self):
        return Path(self.data.project_dir) / ".venv" / "invenio-cli"

    def should_run(self):
        return not (self._invenio_cli_dir / ".install.ok").exists()

==> oarepo-cli-11.0.2.tar.gz: oarepo-cli-11.0.2/oarepo_cli/cli/initialize/step_04_install_invenio_cli.py <==
from __future__ import annotations

import os
import shutil
import venv
from pathlib import Path

from oarepo_cli.ui.wizard import WizardStep

from ...utils import pip_install, run_cmdline


class InstallInvenioCliStep(WizardStep):
    def __init__(self, **kwargs):
        super().__init__(
            heading="""I will install invenio command-line client. I will use the client to check that
you have all the tools installed (python, docker, ...). If this step fails, please fix the problem
and run this wizard again.

Before the installation, you may have a look at the requirements at
https://inveniordm.docs.cern.ch/install/requirements/ .
            """,
            **kwargs,
        )

    def after_run(self):
        print("Creating invenio-cli virtualenv")
        invenio_cli_dir = self._invenio_cli_dir
        self.data["invenio_cli"] = str(
            (invenio_cli_dir / "bin" / "invenio-cli").relative_to(self.data.project_dir)
        )
        if invenio_cli_dir.exists():
            shutil.rmtree(invenio_cli_dir)
        venv.main([str(invenio_cli_dir)])

        pip_install(invenio_cli_dir / "bin" / "pip", "INVENIO_CLI_VERSION", "invenio-cli==1.0.16", "https://github.com/inveniosoftware/invenio-cli")
        
        with open(invenio_cli_dir / ".install.ok", "w") as f:
            f.write("invenio installation ok")

    @property
    def _invenio_cli_dir(self):
        return Path(self.data.project_dir) / ".venv" / "invenio-cli"

    def should_run(self):
        return not (self._invenio_cli_dir / ".install.ok").exists()
